@@ -5,8 +5,6 @@
 import os, sys, syst3m ; sys.path.insert(1, syst3m.defaults.source_path(__file__, back=2))
 from ssht00ls.classes.config import *
 import ssht00ls
-#print(ssht00ls.ssync.index("/tmp/testmount.small", alias="dev.vandenberghinc.com"))
-#quit()
 
 # the cli object class.
 class CLI(cl1.CLI):
@@ -15,7 +13,7 @@ class CLI(cl1.CLI):
 		# defaults.
 		cl1.CLI.__init__(self,
 			modes={
-				"Aliases:":"",
+				"Aliases:":"*chapter*",
 				"    --create-alias":"Create a ssh alias.",
 				"        --server myserver":"Specify the server's name.",
 				"        --username myuser":"Specify the username.",
@@ -27,16 +25,16 @@ class CLI(cl1.CLI):
 				"        for smart cards:":"",
 				"        --smart-cards":"Enable the smart cards boolean.",
 				"        --pin 123456":"Specify the smart cards pin code (optional).",
-				"Keys:":"",
+				"Keys:":"*chapter*",
 				"    --generate":"Generate a ssh key.",
 				"        --path /keys/mykey/":"Specify the keys directory path.",
 				"        --passphrase Passphrase123":"Specify the keys passphrase.",
 				"        --comment 'My Key'":"Specify the keys comment.",
-				"Sessions:":"",
+				"Sessions:":"*chapter*",
 				"    --command <alias> 'ls .'":"Execute a command over ssh.",
 				"    --session <alias>":"Start a ssh session.",
 				"        --options '' ":"Specify additional ssh options (optional).",
-				"Push & pull:":"",
+				"Push & pull:":"*chapter*",
 				"    --pull <path> <alias>:<remote>":"Pull a file / directory.",
 				"        --delete":"Also update the deleted files (optional).",
 				"        --safe":"Enable version control.",
@@ -45,19 +43,19 @@ class CLI(cl1.CLI):
 				"        --delete":"Also update the deleted files (optional).",
 				"        --safe":"Enable version control.",
 				"        --forced":"Enable forced mode.",
-				"Mounts:":"",
+				"Mounts:":"*chapter*",
 				"    --mount <alias>:<remote> <path>":"Mount a remote directory.",
 				"    --unmount <path>":"Unmount a mounted remote directory.",
 				"        --sudo":"Root permission required.",
 				"        --forced":"Enable forced mode.",
 				"    --index <path> / <alias>:<remote>":"Index the specified path / alias:remote.",
-				"Agent:":"",
+				"Agent:":"*chapter*",
 				"    --start-agent":"Start the ssht00ls agent manually.",
 				"    --stop-agent":"Stop the ssht00ls agent.",
-				"Daemons:":"",
+				"Daemons:":"*chapter*",
 				"    --start-daemon <alias>:<remote> <path>":"Start a ssync daemon manually.",
 				"    --stop-daemon <path>":"Stop a ssync daemon.",
-				"Basic:":"",
+				"Basic:":"*chapter*",
 				"    --kill <identifier>":"Kill all ssh processes that include the identifier.",
 				"    --config":"Edit the ssht00ls configuration file (nano).",
 				"    -h / --help":"Show the documentation.",
@@ -76,11 +74,11 @@ class CLI(cl1.CLI):
 	def start(self):
 		
 		# check arguments.
-		self.arguments.check(json=JSON)
+		self.arguments.check(exceptions=["--log-level", "--create-alias"], json=JSON)
 
 		# help.
 		if self.arguments.present(['-h', '--help']):
-			self.docs(success=True, chapter=None, json=JSON)
+			self.docs(success=True, json=JSON)
 
 		# check create ssh config.
 		elif self.arguments.present('--create-alias'):
@@ -90,17 +88,17 @@ class CLI(cl1.CLI):
 				key = self.arguments.get('--key')
 				response = ssht00ls.aliases.create( 
 					# the alias.
-					alias=self.arguments.get('--alias'), 
+					alias=self.arguments.get('--alias', chapter="aliases", mode="--create-alias"), 
 					# the username.
-					username=self.arguments.get('--username'), 
+					username=self.arguments.get('--username'), chapter="aliases", mode="--create-alias", 
 					# the public ip of the server.
-					public_ip=self.arguments.get('--public-ip'),
+					public_ip=self.arguments.get('--public-ip', chapter="aliases", mode="--create-alias"),
 					# the public port of the server.
-					public_port=self.arguments.get('--public-port'),
+					public_port=self.arguments.get('--public-port', chapter="aliases", mode="--create-alias"),
 					# the private ip of the server.
-					private_ip=self.arguments.get('--private-ip'),
+					private_ip=self.arguments.get('--private-ip', chapter="aliases", mode="--create-alias"),
 					# the private port of the server.
-					private_port=self.arguments.get('--private-port'),
+					private_port=self.arguments.get('--private-port', chapter="aliases", mode="--create-alias"),
 					# the path to the private key.
 					key=key,
 					passphrase=getpass.getpass("Enter the passphrase of key [{key}]:"),
@@ -111,22 +109,22 @@ class CLI(cl1.CLI):
 			else:
 				response = ssht00ls.aliases.create( 
 					# the alias.
-					alias=self.arguments.get('--alias'), 
+					alias=self.arguments.get('--alias', chapter="aliases", mode="--create-alias"), 
 					# the username.
-					username=self.arguments.get('--username'), 
+					username=self.arguments.get('--username', chapter="aliases", mode="--create-alias"), 
 					# the public ip of the server.
-					public_ip=self.arguments.get('--public-ip'),
+					public_ip=self.arguments.get('--public-ip', chapter="aliases", mode="--create-alias"),
 					# the public port of the server.
-					public_port=self.arguments.get('--public-port'),
+					public_port=self.arguments.get('--public-port', chapter="aliases", mode="--create-alias"),
 					# the private ip of the server.
-					private_ip=self.arguments.get('--private-ip'),
+					private_ip=self.arguments.get('--private-ip', chapter="aliases", mode="--create-alias"),
 					# the private port of the server.
-					private_port=self.arguments.get('--private-port'),
+					private_port=self.arguments.get('--private-port', chapter="aliases", mode="--create-alias"),
 					# the path to the private key.
 					key=smart_card.path,
 					# smart card.
 					smart_card=True,
-					pin=self.arguments.get('--pin', required=False, default=None), )
+					pin=self.arguments.get('--pin', required=False, default=None, chapter="aliases", mode="--create-alias"), )
 
 			# log to console.
 			self.stop(response=response, json=JSON)
@@ -138,9 +136,9 @@ class CLI(cl1.CLI):
 			passphrase = self.get_passphrase(required=False)
 			if passphrase in ["", None, "null", "None", "none"]: passphrase = None
 			response = ssht00ls.key.generate(
-				path=self.arguments.get("--path"), 
+				path=self.arguments.get("--path", chapter="keys", mode="--generate"), 
 				passphrase=passphrase, 
-				comment=self.arguments.get("--comment"),)
+				comment=self.arguments.get("--comment", chapter="keys", mode="--generate"),)
 			self.stop(response=response, json=JSON)
 
 		# kill ssh processes.
@@ -152,18 +150,21 @@ class CLI(cl1.CLI):
 
 		# pull.
 		elif self.arguments.present('--pull'):
-			remote = self.arguments.get("--pull", index=1)
-			path = self.arguments.get("--pull", index=2)
+			remote = self.arguments.get("--pull", index=1, chapter="push & pull", mode="--pull")
+			path = self.arguments.get("--pull", index=2, chapter="push & pull", mode="--pull")
 			if ":" not in remote:
 				self.docs(
 					error=f"Invalid <alias>:<remote> <path> format.", 
 					chapter="push & pull", 
 					mode="--pull", 
+					notes={
+						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
+					},
 					json=JSON,)
 			alias,remote = remote.split(":")
 			exclude = None
 			if self.arguments.present("--exclude"): 
-				exclude = self.arguments.get("--exclude").split(",")
+				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--pull").split(",")
 			elif self.arguments.present("--no-exclude"): exclude = []
 			response = ssht00ls.ssync.pull(
 				alias=alias, 
@@ -177,18 +178,21 @@ class CLI(cl1.CLI):
 
 		# push.
 		elif self.arguments.present('--push'):
-			path = self.arguments.get("--push", index=1)
-			remote = self.arguments.get("--push", index=2)
+			path = self.arguments.get("--push", index=1, chapter="push & pull", mode="--push")
+			remote = self.arguments.get("--push", index=2, chapter="push & pull", mode="--push")
 			if ":" not in remote:
 				self.docs(
 					error=f"Invalid <alias>:<remote> <path>.", 
 					chapter="push & pull", 
 					mode="--push", 
+					notes={
+						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
+					},
 					json=JSON,)
 			alias,remote = remote.split(":")
 			exclude = None
 			if self.arguments.present("--exclude"): 
-				exclude = self.arguments.get("--exclude").split(",")
+				exclude = self.arguments.get("--exclude", chapter="push & pull", mode="--push").split(",")
 			elif self.arguments.present("--no-exclude"): exclude = []
 			response = ssht00ls.ssync.push(
 				alias=alias, 
@@ -202,13 +206,16 @@ class CLI(cl1.CLI):
 
 		# mount.
 		elif self.arguments.present('--mount'):
-			remote = self.arguments.get("--mount", index=1)
-			path = self.arguments.get("--mount", index=2)
+			remote = self.arguments.get("--mount", index=1, chapter="mounts", mode="--mount", notes={})
+			path = self.arguments.get("--mount", index=2, chapter="mounts", mode="--mount", notes={})
 			if ":" not in remote:
 				self.docs(
 					error=f"Invalid <alias>:<remote> <path>.", 
 					chapter="mounts", 
 					mode="--mount", 
+					notes={
+						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
+					},
 					json=JSON,)
 			alias,remote = remote.split(":")
 			response = ssht00ls.ssync.mount(
@@ -220,7 +227,7 @@ class CLI(cl1.CLI):
 
 		# unmount.
 		elif self.arguments.present('--unmount'):
-			path = self.arguments.get("--unmount", index=1)
+			path = self.arguments.get("--unmount", index=1, chapter="mounts", mode="--unmount")
 			response = ssht00ls.ssync.unmount(
 				path=path,
 				forced=self.arguments.present("--forced"), 
@@ -229,7 +236,7 @@ class CLI(cl1.CLI):
 
 		# index.
 		elif self.arguments.present('--index'):
-			index = self.arguments.get("--index")
+			index = self.arguments.get("--index", chapter="mounts", mode="--index")
 			if ":" in index:
 				alias,remote = index.split(":")
 				response = ssht00ls.ssync.index(path=remote, alias=alias)
@@ -239,13 +246,16 @@ class CLI(cl1.CLI):
 
 		# start daemon.
 		elif self.arguments.present('--start-daemon'):
-			remote = self.arguments.get("--start-daemon", index=1)
-			path = self.arguments.get("--start-daemon", index=2)
+			remote = self.arguments.get("--start-daemon", index=1, chapter="daemons", mode="--start-daemon")
+			path = self.arguments.get("--start-daemon", index=2, chapter="daemons", mode="--start-daemon")
 			if ":" not in remote:
 				self.docs(
 					error=f"Invalid <alias>:<remote> <path>.", 
-					chapter="mounts", 
-					mode="--mount", 
+					chapter="damons", 
+					mode="--start-daemon", 
+					notes={
+						"<alias>:<path>":"Pack the alias & tuple together as one argument in the following format [<alias>:<path>]."
+					},
 					json=JSON,)
 			alias,remote = remote.split(":")
 			response = ssht00ls.ssync.daemon(alias=alias, remote=remote, path=path)
@@ -253,7 +263,7 @@ class CLI(cl1.CLI):
 
 		# stop daemon.
 		elif self.arguments.present('--stop-daemon'):
-			path = self.arguments.get("--stop-daemon", index=1)
+			path = self.arguments.get("--stop-daemon", index=1, chapter="daemon", mode="--stop-daemon")
 			response = ssht00ls.ssync.stop_daemon(path)
 			self.stop(response=response, json=JSON)
 
