@@ -29,7 +29,7 @@ class SmartCards(object):
 					break
 			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
 					
-		elif OS in ["osx"]: 
+		elif OS in ["macos"]: 
 			#self.original_path = "/usr/local/lib/libykcs11.dylib"
 			#self.path = "/usr/local/lib/libykcs11_NOTALNK.dylib"
 			#self.original_path = "/usr/local/lib/opensc-pkcs11.so"
